summaryrefslogtreecommitdiff
path: root/generate
diff options
context:
space:
mode:
author <ole.andre.ravnaas@collabora.co.uk>2006-04-05 08:51:20 +0000
committer <ole.andre.ravnaas@collabora.co.uk>2006-04-05 08:51:20 +0000
commitd6a1549d45796842492aa8595eaf364b295dabc5 (patch)
tree89edbcd9ddee1649ce2a8db161fe3e0b632b452f /generate
parent99d3e5131972606b646989e3150e9d7b06ee2157 (diff)
Integrate boilerplate code for MUC RoomProperties.
Diffstat (limited to 'generate')
-rw-r--r--generate/src/gabble-muc-channel-signals-marshal.list2
-rw-r--r--generate/src/gabble-muc-channel.c60
-rw-r--r--generate/src/gabble-muc-channel.h5
3 files changed, 54 insertions, 13 deletions
diff --git a/generate/src/gabble-muc-channel-signals-marshal.list b/generate/src/gabble-muc-channel-signals-marshal.list
index d6c2c2b3d..26b5e4aba 100644
--- a/generate/src/gabble-muc-channel-signals-marshal.list
+++ b/generate/src/gabble-muc-channel-signals-marshal.list
@@ -2,5 +2,7 @@ VOID:VOID
VOID:INT,INT
VOID:STRING,BOXED,BOXED,BOXED,BOXED
VOID:INT,INT
+VOID:BOXED
+VOID:BOXED
VOID:INT,INT,INT,INT,STRING
VOID:INT,INT,STRING
diff --git a/generate/src/gabble-muc-channel.h b/generate/src/gabble-muc-channel.h
index 2fa9ebb35..be17ba1dc 100644
--- a/generate/src/gabble-muc-channel.h
+++ b/generate/src/gabble-muc-channel.h
@@ -62,15 +62,16 @@ gboolean gabble_muc_channel_get_handle (GabbleMucChannel *obj, guint* ret, guint
gboolean gabble_muc_channel_get_interfaces (GabbleMucChannel *obj, gchar *** ret, GError **error);
gboolean gabble_muc_channel_get_local_pending_members (GabbleMucChannel *obj, GArray ** ret, GError **error);
gboolean gabble_muc_channel_get_members (GabbleMucChannel *obj, GArray ** ret, GError **error);
-gboolean gabble_muc_channel_get_password (GabbleMucChannel *obj, gchar ** ret, GError **error);
gboolean gabble_muc_channel_get_password_flags (GabbleMucChannel *obj, guint* ret, GError **error);
+gboolean gabble_muc_channel_get_properties (GabbleMucChannel *obj, const GArray * properties, GHashTable ** ret, GError **error);
gboolean gabble_muc_channel_get_remote_pending_members (GabbleMucChannel *obj, GArray ** ret, GError **error);
gboolean gabble_muc_channel_get_self_handle (GabbleMucChannel *obj, guint* ret, GError **error);
gboolean gabble_muc_channel_list_pending_messages (GabbleMucChannel *obj, GPtrArray ** ret, GError **error);
+gboolean gabble_muc_channel_list_properties (GabbleMucChannel *obj, GHashTable ** ret, GError **error);
gboolean gabble_muc_channel_provide_password (GabbleMucChannel *obj, const gchar * password, DBusGMethodInvocation *context);
gboolean gabble_muc_channel_remove_members (GabbleMucChannel *obj, const GArray * contacts, const gchar * message, GError **error);
gboolean gabble_muc_channel_send (GabbleMucChannel *obj, guint type, const gchar * text, GError **error);
-gboolean gabble_muc_channel_set_password (GabbleMucChannel *obj, const gchar * password, GError **error);
+gboolean gabble_muc_channel_set_properties (GabbleMucChannel *obj, GHashTable * properties, GError **error);
G_END_DECLS
diff --git a/generate/src/gabble-muc-channel.c b/generate/src/gabble-muc-channel.c
index 463b969c9..a3810365e 100644
--- a/generate/src/gabble-muc-channel.c
+++ b/generate/src/gabble-muc-channel.c
@@ -36,6 +36,8 @@ enum
GROUP_FLAGS_CHANGED,
MEMBERS_CHANGED,
PASSWORD_FLAGS_CHANGED,
+ PROPERTIES_CHANGED,
+ PROPERTY_FLAGS_CHANGED,
RECEIVED,
SENT,
LAST_SIGNAL
@@ -110,6 +112,24 @@ gabble_muc_channel_class_init (GabbleMucChannelClass *gabble_muc_channel_class)
gabble_muc_channel_marshal_VOID__INT_INT,
G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_UINT);
+ signals[PROPERTIES_CHANGED] =
+ g_signal_new ("properties-changed",
+ G_OBJECT_CLASS_TYPE (gabble_muc_channel_class),
+ G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+ 0,
+ NULL, NULL,
+ gabble_muc_channel_marshal_VOID__BOXED,
+ G_TYPE_NONE, 1, (dbus_g_type_get_map ("GHashTable", G_TYPE_UINT, G_TYPE_VALUE)));
+
+ signals[PROPERTY_FLAGS_CHANGED] =
+ g_signal_new ("property-flags-changed",
+ G_OBJECT_CLASS_TYPE (gabble_muc_channel_class),
+ G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+ 0,
+ NULL, NULL,
+ gabble_muc_channel_marshal_VOID__BOXED,
+ G_TYPE_NONE, 1, (dbus_g_type_get_map ("GHashTable", G_TYPE_UINT, G_TYPE_UINT)));
+
signals[RECEIVED] =
g_signal_new ("received",
G_OBJECT_CLASS_TYPE (gabble_muc_channel_class),
@@ -324,9 +344,9 @@ gboolean gabble_muc_channel_get_members (GabbleMucChannel *obj, GArray ** ret, G
/**
- * gabble_muc_channel_get_password
+ * gabble_muc_channel_get_password_flags
*
- * Implements DBus method GetPassword
+ * Implements DBus method GetPasswordFlags
* on interface org.freedesktop.Telepathy.Channel.Interface.Password
*
* @error: Used to return a pointer to a GError detailing any error
@@ -335,17 +355,17 @@ gboolean gabble_muc_channel_get_members (GabbleMucChannel *obj, GArray ** ret, G
*
* Returns: TRUE if successful, FALSE if an error was thrown.
*/
-gboolean gabble_muc_channel_get_password (GabbleMucChannel *obj, gchar ** ret, GError **error)
+gboolean gabble_muc_channel_get_password_flags (GabbleMucChannel *obj, guint* ret, GError **error)
{
return TRUE;
}
/**
- * gabble_muc_channel_get_password_flags
+ * gabble_muc_channel_get_properties
*
* Implements DBus method GetPasswordFlags
* on interface org.freedesktop.Telepathy.Channel.Interface.Password
*
* @error: Used to return a pointer to a GError detailing any error
* that occured, DBus will throw the error only if this
@@ -353,7 +373,7 @@ gboolean gabble_muc_channel_get_password (GabbleMucChannel *obj, gchar ** ret, G
*
* Returns: TRUE if successful, FALSE if an error was thrown.
*/
-gboolean gabble_muc_channel_get_password_flags (GabbleMucChannel *obj, guint* ret, GError **error)
+gboolean gabble_muc_channel_get_properties (GabbleMucChannel *obj, const GArray * properties, GHashTable ** ret, GError **error)
{
return TRUE;
}
@@ -414,6 +434,24 @@ gboolean gabble_muc_channel_list_pending_messages (GabbleMucChannel *obj, GPtrAr
/**
+ * gabble_muc_channel_list_properties
+ *
+ * Implements DBus method ListProperties
+ * on interface org.freedesktop.Telepathy.Channel.Interface.RoomProperties
+ *
+ * @error: Used to return a pointer to a GError detailing any error
+ * that occured, DBus will throw the error only if this
+ * function returns false.
+ *
+ * Returns: TRUE if successful, FALSE if an error was thrown.
+ */
+gboolean gabble_muc_channel_list_properties (GabbleMucChannel *obj, GHashTable ** ret, GError **error)
+{
+ return TRUE;
+}
+
+
+/**
* gabble_muc_channel_provide_password
*
* Implements DBus method ProvidePassword
@@ -465,10 +503,10 @@ gboolean gabble_muc_channel_send (GabbleMucChannel *obj, guint type, const gchar
/**
- * gabble_muc_channel_set_password
+ * gabble_muc_channel_set_properties
*
* Implements DBus method SetPassword
* on interface org.freedesktop.Telepathy.Channel.Interface.Password
*
* @error: Used to return a pointer to a GError detailing any error
* that occured, DBus will throw the error only if this
@@ -476,7 +514,7 @@ gboolean gabble_muc_channel_send (GabbleMucChannel *obj, guint type, const gchar
*
* Returns: TRUE if successful, FALSE if an error was thrown.
*/
-gboolean gabble_muc_channel_set_password (GabbleMucChannel *obj, const gchar * password, GError **error)
+gboolean gabble_muc_channel_set_properties (GabbleMucChannel *obj, GHashTable * properties, GError **error)
{
return TRUE;
}
@@ -335,17 +355,17 @@ gboolean gabble_muc_channel_get_members (GabbleMucChannel *obj, GArray ** ret, G
*
- * Implements DBus method GetPasswordFlags
- * on interface org.freedesktop.Telepathy.Channel.Interface.Password
+ * Implements DBus method GetProperties
+ * on interface org.freedesktop.Telepathy.Channel.Interface.RoomProperties
*
* @error: Used to return a pointer to a GError detailing any error
@@ -465,10 +503,10 @@ gboolean gabble_muc_channel_send (GabbleMucChannel *obj, guint type, const gchar
*
- * Implements DBus method SetPassword
- * on interface org.freedesktop.Telepathy.Channel.Interface.Password
+ * Implements DBus method SetProperties
+ * on interface org.freedesktop.Telepathy.Channel.Interface.RoomProperties
*
* @error: Used to return a pointer to a GError detailing any error